#
# spec file for package libhugetlbfs
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define my_make_flags V=1 CFLAGS="%{optflags} -fPIC" BUILDTYPE=NATIVEONLY PREFIX=%{_prefix} LIBDIR32=%{_libdir} DESTDIR=%{buildroot}
Name:           libhugetlbfs
Version:        2.20
Release:        lp152.3.9
Summary:        Helper library for the Huge Translation Lookaside Buffer Filesystem
License:        LGPL-2.1+
Group:          System/Libraries
Url:            https://github.com/libhugetlbfs/libhugetlbfs
Source0:        %{name}-%{version}.tar.xz
Source1:        baselibs.conf
Patch2:         libhugetlbfs.s390.patch
Patch4:         libhugetlbfs.tests-malloc.patch
Patch7:         libhugetlbfs_ia64_fix_missing_test.patch
Patch8:         libhugetlbfs_fix_tests.patch
Patch13:        ignore-perl-modules.diff
Patch14:        disable-rw-on-non-ldscripts.diff
Patch15:        zero_filesize_segment.patch
BuildRequires:  doxygen
BuildRequires:  glibc-devel-static
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# bug437293
%ifarch ppc64
Obsoletes:      libhugetlbfs-64bit
%endif

%description
The libhugetlbfs package interacts with the Linux hugetlbfs to
make large pages available to applications in a transparent manner.

%package devel
Summary:        Development files for libhugetlbfs
Group:          Development/Libraries/C and C++
Requires:       libhugetlbfs

%description devel
Devel package, header and static library, of libhugetlbfs.

%package tests
Summary:        Tests for package libhugetlbfs
Group:          Development/Tools/Other

%description tests
The testsuite for libhugetlbfs. Binaries can be found in
%{_libdir}/libhugetlbfs/tests.

%prep
%setup -q
%patch2 -p1
%patch4 -p1
%patch7 -p1
%patch8 -p1
%patch13
%patch14
%patch15 -p1

%build
echo %{version} > version
make %{my_make_flags}

%install
make %{my_make_flags} PMDIR="%{perl_vendorlib}/TLBC" \
	install install-perlmod install-tests
mkdir -p %{buildroot}%{_prefix}/include
cp -avL hugetlbfs.h %{buildroot}%{_prefix}/include
chmod 644 %{buildroot}%{_libdir}/*.a
if [ -f %{buildroot}%{_libdir}/libhugetlbfs/tests/obj64/dummy.ldscript ]; then
	chmod -f a-x %{buildroot}%{_libdir}/libhugetlbfs/tests/obj64/dummy.ldscript
fi

%files
%defattr(-, root, root)
%doc LGPL-2.1 HOWTO README NEWS
%{_datadir}/libhugetlbfs
%{_bindir}/*
%{_mandir}/man[178]/*%{?ext_man}
%{_libdir}/libhugetlbfs_privutils.so
%{_libdir}/libhugetlbfs.so
%{perl_vendorlib}/TLBC/

%files devel
%defattr(-, root, root)
%{_includedir}/hugetlbfs.h
%{_libdir}/libhugetlbfs.a
%{_mandir}/man3/*%{?ext_man}

%files tests
%defattr(-,root,root)
%{_libdir}/libhugetlbfs/

%changelog
* Mon Sep 11 2017 jengelh@inai.de
- Run `make install-perlmod` to install/satisfy Perl modules
  required by /usr/bin/cpupcstat, itself installed by just
  `make install` [boo#1057963]
* Thu Apr 20 2017 jengelh@inai.de
- Update summary and descriptions a bit
- Move development manpages (*.3) to development subpackage
- Avoid ||/&& in %%install because it can leave $? at non-zero
  (unlike if..fi), and %%install is run with sh -x.
* Thu Mar  9 2017 fschnizlein@suse.com
- Update to 2.20
- Bug Fixes:
  * Fix keyword collisions and warnings from GCC 5
  * hugeadm output is parsed for default size in huge_page_setup_helper
  * Testsuite: fallocate tests
* Fri Nov  6 2015 fvogt@suse.com
- Add zero_filesize_segment.patch to fix testcase on s390x
- Fixes bnc#919680
- Patches already included mainline and now deleted:
  D libhugetlbfs-2.18-restrict-is-a-reserved-word.patch
  D fix_plt_extrasz_always_returning_0_on_ppc64le.patch
* Fri Nov  6 2015 fvogt@suse.com
- Latest version from git next branch
* Tue Jun 23 2015 antoine.belvire@laposte.net
- Add libhugelbfs-2.18-restrict-is-a-reserved-word.patch which
  fixes compilation with GCC 5 (and C99/C11 in general).
  * Add libhugetlbfs-2.18-restrict-is-a-reserved-word.patch
* Fri Feb 20 2015 normand@linux.vnet.ibm.com
- update to 2.18
  to solve build failures for ppc/ppc64.
  remove following patches now included in 2.18:
    libhugetlbfs-ppc64le.patch
    libhugetlbfs.ppc64le.step2.patch
    libhugetlbfs.ppc64le.step3.patch
    libhugetlbfs.ppc64le.step4.patch
- Add fix_plt_extrasz_always_returning_0_on_ppc64le.patch
  already upstream.
* Wed Mar 26 2014 dmueller@suse.com
- update to 2.17:
  * PPC segement alignment restrictions can be disabled
  * Added Aarch64 support
  * Allow compiler overrides for 64 and 32 bit builds
  * hugeadm now handles /etc/mtab being a simlink properly
  * ppc64 fixes
- remove libhugetlbfs.ia64-libdir.patch:
  ia64 is no longer supported by openSUSE
- add ignore-perl-modules.diff: do not install perl modules, unused
  and are installed in the wrong place to be found anyway
- add ARM support
- add disable-rw-on-non-ldscripts.diff: Skip rw tests
- Do not install tests anymore
* Tue Feb 11 2014 trenn@suse.de
- Tests compile fine for s390(x), also include them in the package, the same
  way it is done for other archs as well.
* Mon Feb 10 2014 trenn@suse.de
- There are no tests installed in s390(x) case, therefore there are no
  files in %%{_libdir}/libhugetlbfs
  Remove the directory from the file list to fix package build for s390(x)
* Sat Jan 11 2014 normand@linux.vnet.ibm.com
- Add support of ppc64le with 4 patches
  libhugetlbfs-ppc64le.patch
  libhugetlbfs.ppc64le.step2.patch
  libhugetlbfs.ppc64le.step3.patch
  libhugetlbfs.ppc64le.step4.patch
* Mon Mar 11 2013 trenn@suse.de
- Update to version 2.16:
  Features:
  * ARM Support
  * s390x Dynamic TASK_SIZE support
  Bug Fixes:
  * find_mounts() now properly NULL terminates mount point names
* Wed Jan 23 2013 trenn@suse.de
- Update to version 2.15
  Features:
  * Some System z functionality went into 2.15
  * Updated man pages
  * Added basic events for core_i7 to oprofile_map_events
  Fixes:
  * Disable Unable to verify address range warning when offset < page_size
  * Remove sscanf in library setup to avoid heap allocation before _morecore
  override
  * Revert heap exhaustion patch
  * hugectl no longer clips LD_LIBRARY_PATH variable
  * Fix clean on failure code to avoid closing stdout
* Wed Jul 11 2012 adrian@suse.de
- Add excludearch for arm due to lacking support
* Tue Apr 10 2012 tabraham@novell.com
- Update to version 2.13
  * hugeadm can now be used to control Transparent Huge Page tunables
  * New morecore mode to better support THP
  * Check permissions on hugetlbfs mount point before marking it as
    available
  * Fix shm tests to use random address instead of fixed, old address
    failed on ARM
* Wed Oct 12 2011 tabraham@novell.com
- Update to version 2.12
  * libhugetlbfs usages can now be restricted to certain binary names
  * libhugetlbfs now supports static linking
  * hugeadm uses more human readable directory names for mount points
  * Fix segfault if specified user was not in passwd, failuer in
    getpwuid() is now checked
  * Added tests for static linking to testcase
  * Added missing tests to driver script
* Sun May 29 2011 meissner@novell.com
- Do not include the 268MB testcase /usr/lib/libhugetlbfs/tests/obj32/linkhuge_rw.
* Fri Dec 17 2010 trenn@novell.com
- Update to version 2.11
  Bugfixes and new features are listed in the NEWS file in
  /usr/share/doc/packages/libhugetlbfs/NEWS
* Wed Oct  6 2010 aj@suse.de
- Update to version 2.9:
  * Add --no-reseve to hugectl to request mmap'd pages are not reserved
    for kernels newer than 2.6.34
  * Add --obey-numa-mempol to hugeadm to request static pool pages are
    allocated following the process NUMA memory policy
  * Add switch to let administrator limit new mount points by size or inodes
  * cpupcstat now caches the value returned by tlmiss_cost.sh to avoid
    rerunning the script
  * When specifying huge page pool sizes with hugeadm, memory sizes can
    be used as well as the number of huge pages
  * DEFAULT is now a valid huge page pool for resizing, it will adjust
    the pool for the default huge page size
  * tlbmiss_cost.sh in the contrib/ sub directory will estimate the cost
    in CPU cycles of a TLB miss on the arch where it is run
  * Add python script which automates huge page pool setup with minimal
    input required from user
  * cpupcstat now supports data collection using the perf tool as well as
    oprofile
  * --explain reports if min_free_kbytes is too small
  * add --set-min_free_kbytes to hugeadm
* Fri Jun 18 2010 coolo@novell.com
- strip test binaries to fix build
* Tue Feb  9 2010 trenn@novell.com
- Removed unused files
* Mon Feb  8 2010 jengelh@medozas.de
- add workarounds for broken Makefile logic to detect arch
* Mon Feb  1 2010 jengelh@medozas.de
- Package baselibs.conf
* Mon Oct 12 2009 aj@suse.de
- Fix typo in requires.
* Wed Jul 29 2009 trenn@suse.de
- Update from version 2.0 to 2.5
* Mon Feb  2 2009 olh@suse.de
- document workaround for NX configurations on x86 (bnc#470234 - LTC50261)
* Wed Jan  7 2009 olh@suse.de
- Update SECTIONS from linker scripts for binutils 2.19 compatibility
  (bnc#445372 - LTC50129)
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Nov  6 2008 olh@suse.de
- fix libhugetlbfs 32bit test case xB.linkhuge failure (bnc#442209 - LTC49702)
* Tue Oct 21 2008 olh@suse.de
- handle older binutils versions in elf32ppclinux.xBDT (bnc#436451 - LTC49076)
* Wed Aug 27 2008 olh@suse.de
- update to version 2.0 (fate#304340)
  New Features
  * New scriptless relinking for binutils >= 2.17
  * Added direct allocator API for huge pages
  Bug Fixes
  * /proc/mounts is parsed line at a time to handle file larger than 4kb
  * Read-only mappings use MAP_NORESERVE
* Wed Jun 25 2008 olh@suse.de
- update to version 1.3
  New features
  * Add HUGETLB_NO_PREFAULT to control prefaulting of huge pages via mlock
  * Add "[hostname:pid]" to output messages
  * Setup for handling larger huge page sizes e.g. 16G huge pages
  * Update for new upstream sysctl
  * Add support for hugetlbfs_morecore to shrink the heap
  Bug fixes
  * Disable heap shrinking by default to avoid bug in glibc malloc
  * Skip elflink calls in setup_libhugetlbfs for IA64 and sparc64
  * Replace gethugepagesize with check_hugepagesize for error checking
  * Make morecore argument a long to handle larger page sizes
  Tets suite fixes
  * Check uid/gid in tests where it matters
  * tests: verify there are enough huge pages
  * Change tests to read /proc/meminfo
  * tests: verify that huge page size isn't too big for the test
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Mon Jan 14 2008 olh@suse.de
- update to version 1.2
  New features
  * Partial segment remapping. This allows non-relinked binaries to try
    to take advantage of libhugetlbfs' segment remapping code. Large
    segments are required, especially on Power. This feature is useful
    for estimating huge page performance, however full relinking will
    still perform better.
  * Add extra debugging for binaries that may run out of address space.
  * Log library version when HUGETLB_VERBOSE is enabled.
  * New test to check handling of misaligned mmap() parameters.
  Bug fixes
  * Fix EH_FRAME segment. Fixes some C++ applications.
  * Rework PLT detection to work better on Power.
  * Add per-target-arch syscall stubs to the library. These provide
    reliable error messages from elflink.c if they occur while the
    program segments are unmapped.
  * Add proper SONAME to shared libs.
  * Makefile respects CFLAGS/LDFLAGS/CPPFLAGS environment variables.
  * Make mlock() failure non-fatal.
* Sun Jul  8 2007 olh@suse.de
- disable zero_filesize_segment test
* Sun Apr 15 2007 olh@suse.de
- update to version 1.1 (262564 - LTC33711)
* Mon Feb  5 2007 olh@suse.de
- update to 20070129 devel snapshot
  drop hugetlbd
* Mon Feb  5 2007 olh@suse.de
- build -m64/-m32 if required
* Sat Dec  9 2006 olh@suse.de
- build with -g
  make install should not depend on all
* Fri Dec  8 2006 olh@suse.de
- package testsuite, fix make check
* Tue Dec  5 2006 olh@suse.de
- add the hugetlbd (214426)
* Sun Oct 29 2006 olh@suse.de
- update to bugfix release 1.0.1 (214426)
  * Always install linker scripts for all targets
  * Error message updates
  * Add documentation on HUGETLB_DEBUG
  * Testcase updates
* Thu Oct  5 2006 olh@suse.de
- update to final 1.0
* Tue Sep 19 2006 olh@suse.de
- update to 20060913 git state
  docu updates
  use library versioning
* Wed Jul 19 2006 olh@suse.de
- update to 1.0-pre3
* Tue Apr 18 2006 olh@suse.de
- drop unneeded -packages from Buildrequires
* Sat Apr  8 2006 olh@suse.de
- update to 1.0-pre2 (#142046 - LTC20562)
* Tue Feb 21 2006 olh@suse.de
- remove backup files
* Tue Feb 21 2006 olh@suse.de
- add linker scripts on ppc, ppc64, i386 and x86_64
* Thu Feb  9 2006 olh@suse.de
- create package, version 1.0-pre1 (#142046 - LTC20562)
